#!/bin/sh
#
# Test for 3 different latencies, for traditional copy and copy offload.
# Test for different file sizes.
#
# Copyright 2010 NetApp, Inc.,
# contribution by Anshul Madan
# contribution by James Lentini
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License v2 for more details.

CAT=/bin/cat
CP=/bin/cp
COPY=./copy
ECHO=/bin/echo


#
# Function: usage
#
usage() {
	$ECHO "Usage: $0 [-c] [-r] <type> <source file> <destination file>"
	$ECHO "Where"
	$ECHO -e "\t -c : clear the page cache after the copy and before a read"
	$ECHO -e "\t -r : read the destination file after the copy"
	$ECHO -e "\t type : either \"traditional\" or \"offload\""
	exit 1
}


#
# Main
#

clear_flag=
read_flag=
while getopts 'crt' OPTION
do
	case $OPTION in
	c)	clear_flag=1
			;;
	r)	read_flag=1
			;;
	?)	usage
			;;
	esac
done
shift $(($OPTIND - 1))

if [ 3 -ne $# ]; then
	usage
fi

type=$1
src=$2
dst=$3

if [ "$type" = "traditional" ]; then
	$CP $src $dst
else
	$COPY -q $src $dst
fi

if [ "$clear_flag" ]
then
	$ECHO 3 > /proc/sys/vm/drop_caches
fi

if [ "$read_flag" ]
then
	$CAT $dst > /dev/null
fi
