#
# gnuplot script file
#
# Copyright 2010 NetApp, Inc.,
# contribution by James Lentini
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License v2 for more details.


#
# Create a graph of the time data
#
set terminal png
set output 'copy-time.png'
set title 'Copy Time'
set xlabel 'File size (MB)'
set ylabel 'Time (seconds)' 
set logscale x
set xtics 2
set xrange [2:2048]
set y2tics
set key bmargin center

plot 'time.dat' index 0 every 3::0 using 1:4 smooth unique with linespoints title 'Local Copy', \
     'time.dat' index 0 every 3::1 using 1:4 smooth unique with linespoints title 'Traditional NFS Copy', \
     'time.dat' index 0 every 3::2 using 1:4 smooth unique with linespoints title 'Offloaded NFS Copy'

#
# Create a sub-graph of the time data
#
set terminal png
set output 'copy-time-detail.png'
set title 'Copy Time'
set xlabel 'File size (MB)'
set ylabel 'Time (seconds)' 
set logscale x
set xtics 2
set xrange [2:512]
set y2tics
set key bmargin center

plot 'time.dat' index 0 every 3::0 using 1:4 smooth unique with linespoints title 'Local Copy', \
     'time.dat' index 0 every 3::1 using 1:4 smooth unique with linespoints title 'Traditional NFS Copy', \
     'time.dat' index 0 every 3::2 using 1:4 smooth unique with linespoints title 'Offloaded NFS Copy'

#
# Create a graph of the packet data
#
set terminal png
set output 'copy-packet.png'
set title 'Copy Packets'
set xlabel 'File size (MB)'
set ylabel 'Packets (Ethernet frames)' 
set logscale x
set xtics 2
set xrange [2:2048]
set y2tics
set key bmargin center

plot 'packet.dat' index 0 every 3::1 using 1:( ($8 + $9) - ($4 + $5) ) smooth unique with linespoints title 'Traditional NFS Copy (client)', \
     'packet.dat' index 0 every 3::1 using 1:( ($10 + $11) - ($6 + $7) ) smooth unique with linespoints title 'Traditional NFS Copy (server)', \
     'packet.dat' index 0 every 3::2 using 1:( ($8 + $9) - ($4 + $5) ) smooth unique with linespoints title 'Offloaded NFS Copy (client)', \
     'packet.dat' index 0 every 3::2 using 1:( ($10 + $11) - ($6 + $7) ) smooth unique with linespoints title 'Offloaded NFS Copy (server)'
